Document class abstract

Document class

Annotations
  • @freezed

Constructors

Document({@Default.new('') String id, @Default.new('') String name, @Default.new('') String type, @Default.new('') String url, @Default.new(0) int width, @Default.new(0) int height, @Default.new(0) int size, @Default.new('') String preview, @Default.new('') String disk, @Default.new('') String hash, @Default.new('') String createdById, @Default.new('') String assignedToId, @Default.new(0) int createdAt, @Default.new(0) int updatedAt, @Default.new(0) int archivedAt, @Default.new(false) bool isDeleted, @Default.new(false) bool isDefault})
Document factory constructor
factory
Document.fromJson(Map<String, dynamic> json)
Create an Document from JSON
factory

Properties

archivedAt → int
no setterinherited
assignedToId → String
no setterinherited
copyWith → $DocumentCopyWith<Document>
no setterinherited
createdAt → int
no setterinherited
createdById → String
no setterinherited
disk → String
no setterinherited
hash → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setterinherited
id → String
no setterinherited
isDefault → bool
no setterinherited
isDeleted → bool
no setterinherited
name → String
no setterinherited
preview → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setterinherited
type → String
no setterinherited
updatedAt → int
no setterinherited
url → String
no setterinherited
width → int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited